pub struct SecurityState {
version: u64,
}Expand description
The security state is a signed object attesting to the security state of a user.
It contains a version, which can only ever increment. Based on the version, old formats and features are blocked. This prevents a server from downgrading a user’s account features, because only the user can create this signed object.
Fields
version: u64The version of the security state gates feature availability. It can only ever be incremented. Components can use it to gate format support of specific formats (like item url hashes).
Implementations
Sourceimpl SecurityState
impl SecurityState
Sourcepub fn new() -> Self
pub fn new() -> Self
Initialize a new SecurityState for the given user ID, to the lowest version possible.
The user needs to be a v2 encryption user.
Sourcepub fn sign<Ids: KeySlotIds>(
&self,
signing_key_id: Ids::Signing,
ctx: &mut KeyStoreContext<'_, Ids>,
) -> Result<SignedSecurityState, CryptoError>
pub fn sign<Ids: KeySlotIds>( &self, signing_key_id: Ids::Signing, ctx: &mut KeyStoreContext<'_, Ids>, ) -> Result<SignedSecurityState, CryptoError>
Signs the SecurityState with the provided signing key ID from the context.